summaryrefslogtreecommitdiff
path: root/__pkginfo__.py
diff options
context:
space:
mode:
authorDavid Douard <david.douard@logilab.fr>2013-06-17 18:09:03 +0200
committerDavid Douard <david.douard@logilab.fr>2013-06-17 18:09:03 +0200
commitde948487c55093839c6c022bff5f45b195637c3d (patch)
treeea29aee5cf6a39fd566a2a5008bef682813d5a39 /__pkginfo__.py
parent71454b097693d33daceb5d83925abfc62c9e12ec (diff)
downloadastroid-de948487c55093839c6c022bff5f45b195637c3d.tar.gz
rename the project astroid
Diffstat (limited to '__pkginfo__.py')
-rw-r--r--__pkginfo__.py17
1 files changed, 8 insertions, 9 deletions
diff --git a/__pkginfo__.py b/__pkginfo__.py
index 65f0778..971de91 100644
--- a/__pkginfo__.py
+++ b/__pkginfo__.py
@@ -1,26 +1,25 @@
# copyright 2003-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
#
# This file is part of logilab-astng.
#
# logilab-astng is free software: you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by the
# Free Software Foundation, either version 2.1 of the License, or (at your
# option) any later version.
#
# logilab-astng is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
# for more details.
#
# You should have received a copy of the GNU Lesser General Public License along
-# with logilab-astng. If not, see <http://www.gnu.org/licenses/>.
-"""logilab.astng packaging information"""
+# with astroid. If not, see <http://www.gnu.org/licenses/>.
+"""astroid packaging information"""
-distname = 'logilab-astng'
+distname = 'astroid'
-modname = 'astng'
-subpackage_of = 'logilab'
+modname = 'astroid'
numversion = (0, 24, 3)
version = '.'.join([str(num) for num in numversion])
@@ -32,7 +31,7 @@ license = 'LGPL'
author = 'Logilab'
author_email = 'python-projects@lists.logilab.org'
mailinglist = "mailto://%s" % author_email
-web = 'http://bitbucket.org/logilab/astng'
+web = 'http://bitbucket.org/logilab/astroid'
description = "rebuild a new abstract syntax tree from Python's ast"
@@ -1,26 +1,25 @@
# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
#
-# This file is part of logilab-astng.
+# This file is part of astroid.
#
@@ -1,26 +1,25 @@
#
-# logilab-astng is free software: you can redistribute it and/or modify it
+# astroid is free software: you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by the
# Free Software Foundation, either version 2.1 of the License, or (at your
@@ -1,26 +1,25 @@
# option) any later version.
#
-# logilab-astng is distributed in the hope that it will be useful, but
+# astroid is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License